@@ -1458,8 +1458,8 @@ faster than ``c.convert_reference_time(cf.Units('days since
 
     units: `cf.Units`, optional
         The reference time units to convert to. By default the units
-        days since the original reference time in the the original
-        calendar.
+        are "days since the original reference time in the original
+        calendar".
 
           *Example:*
             If the original units are ``'months since 2000-1-1'`` in
@@ -3088,8 +3088,7 @@ create bounds based on the coordinate array values.
                 direction = bool(self.direction())
 
                 for c, b in izip(self.dtarray, bounds):
-                    b[...] = cellsize_bounds(*c.timetuple()[:6],
-                                             calendar=calendar, direction=direction)
+                    b[...] = cellsize_bounds(c, direction=direction)
         else:
             if bound is None:
                 # ----------------------------------------------------
