@@ -1278,7 +1278,7 @@ All terms linked to coordinate objects are set to `None`.
                 allclose(value, default, rtol=rtol, atol=atol)):
                 continue
             
-            append((term, value, cu))
+            append((term, value, cu.formatted(definition=True)))
         #--- End: for                
                 
         return tuple(s)
