@@ -2215,16 +2215,64 @@ names:
         return fl
 #--- End: def
 
-def ENVIRONMENT():
-    '''
-'''
-    print 'Platform:'      , platform() 
-    print 'HDF5 library:'  , netCDF4. __hdf5libversion__
-    print 'netcdf library:', netCDF4.__netcdf4libversion__
-    print 'python:'        , python_version()   , sys_executable
-    print 'netCDF4:'       , netCDF4.__version__, os_path_abspath(netCDF4.__file__)
-    print 'numpy:'         , numpy__version__   , os_path_abspath(numpy__file__)
-    print 'psutil:'        , psutil.__version__ , os_path_abspath(psutil.__file__)
-    print 'cf:'            , __version__        , os_path_abspath(__file__)
-#--- End: def
+def environment(display=True):
+    ''':Parameters:
 
+    display: `bool`, optional
+        If False then{+,fef,} return the description of the
+        environment as a string. By default the description is
+        printed.
+
+:Returns:
+
+    out: `None` or `str`
+        If *display* is True then the description of the environment
+        is printed and `None` is returned. Otherwise the description
+        is returned as a string.
+
+:Examples:
+
+>>> cf.environment()
+Platform: Linux-3.13.0-24-generic-x86_64-with-debian-jessie-sid
+HDF5 library: 1.8.17
+netcdf library: 4.4.1
+python: 2.7.12 /home/user/anaconda2/bin/python
+netCDF4: 1.2.4 /home/user/anaconda2/lib/python2.7/site-packages/netCDF4/__init__.pyc
+numpy: 1.11.1 /home/user/anaconda2/lib/python2.7/site-packages/numpy/__init__.pyc
+psutil: 4.3.0 /home/user/anaconda2/lib/python2.7/site-packages/psutil/__init__.pyc
+cfplot: 1.9.21 /home/user/anaconda2/lib/python2.7/site-packages/cfplot/__init__.pyc
+cf: 1.4 /home/user/cf-python/cf/__init__.pyc
+
+    '''
+    out = []
+    out.append('Platform: ' + str(platform()))
+    out.append('HDF5 library: ' + str(netCDF4. __hdf5libversion__))
+    out.append('netcdf library: ' + str(netCDF4.__netcdf4libversion__))
+    out.append('python: ' + str(python_version() + ' ' + str(sys_executable)))
+    out.append('netCDF4: ' + str(netCDF4.__version__) + ' ' + str(os_path_abspath(netCDF4.__file__)))
+    out.append('numpy: ' + str(numpy__version__) + ' ' + str(os_path_abspath(numpy__file__)))
+    out.append('psutil: ' + str(psutil.__version__) + ' ' + str(os_path_abspath(psutil.__file__)))
+
+    try:
+        import ESMF
+    except ImportError:
+        pass
+    else:
+        out.append('ESMF: ' + str(ESMF.__version__) + ' ' + str(os_path_abspath(ESMF.__file__)))
+
+    try:
+        import cfplot
+    except ImportError:
+        pass
+    else:
+        out.append('cfplot: ' + str(cfplot.__version__) + ' ' + str(os_path_abspath(cfplot.__file__)))
+            
+    out.append('cf: ' + str(__version__) + ' ' + str(os_path_abspath(__file__)))
+    
+    out = '\n'.join(out)
+
+    if display:
+        print out
+    else:
+        return out
+#--- End: def
