@@ -18,7 +18,7 @@ def read(files, verbose=False, ignore_read_error=False,
          aggregate=True, sion=4.5, nfields=None, squeeze=False,
          unsqueeze=False, fmt=None, select=None, select_options={},
          top_level=None, height_at_top_of_model=None, recursive=False,
-         follow_symlinks=False, um=None):
+         follow_symlinks=False, um=None, umversion=None):
     '''Read fields from files into `cf.Field` objects.
 
 A file may be on disk or on a OPeNDAP server.
@@ -35,9 +35,9 @@ Office (UK) fields files format files may be read.
      variables objects are not included in the returned list of
      fields.
 
-**PP files**
-   * If any PP files are read then the *aggregate* option
-     ``'relaxed_units'`` is set to True for all input files.
+**PP and fields files**
+   * The *aggregate* option ``'relaxed_units'`` is set to True for all
+     input files.
     
    * STASH code to standard conversion uses the table in
      ``cf/etc/STASH_to_CF.txt``.
@@ -87,18 +87,7 @@ Office (UK) fields files format files may be read.
         If True then print information to stdout.
     
     umversion: `int` or `float`, optional
-        Met Office (UK) PP files and Met Office (UK) fields files
-        only, the Unified Model (UM) version to be used when decoding
-        the PP header. Valid versions are, for example, ``402`` or
-        ``4.2`` (v4.2), ``606.3`` (v6.6.3) and ``1001`` or ``10.1``
-        (v10.1). The default version is ``4.5`` (v4.5). The version is
-        ignored if it can be inferred from the PP headers, which will
-        generally be the case for files created at v5.3 and
-        later. Note that the PP header can not encode tertiary version
-        elements (such as the ``3`` in ``606.3``), so it may be
-        necessary to provide a UM version in such cases.
-    
-        Ignored for any other type of input files.
+        Deprecated. Use the *um* instead.
 
     ignore_read_error: `bool`, optional
         If True then ignore any file which raises an IOError whilst
@@ -109,7 +98,7 @@ Office (UK) fields files format files may be read.
         Only read files of the given format, ignoring all other
         files. Valid formats are ``'NETCDF'`` for CF-netCDF files,
         ``'CFA'`` for CFA-netCDF files and ``'PP'`` for PP files and
-        'FF' for UM fields files. By default files of any of these
+        ``'FF'`` for UM fields files. By default files of any of these
         formats are read.  default files of any of these formats are
         read.
 
@@ -179,6 +168,53 @@ Office (UK) fields files format files may be read.
         parent directory of itself.
 
         .. versionadded:: 1.1.9
+
+    um: `dict`, optional
+        For Met Office (UK) PP files and Met Office (UK) fields files
+        only, provide extra decoding instructions. This option is
+        ignored for input files which are not PP or fields files. In
+        most cases, how to decode a file is inferrable from the file's
+        contents, but if not then each key/value pair in the
+        dictionary sets a decoding option as follows:
+
+          ===============  ===========================================
+          Key              Value
+          ===============  ===========================================
+          ``'fmt'``        The file format (``'PP'`` or ``'FF'``)
+
+          ``'word_size'``  The word size in bytes (``4`` or ``8``)
+
+          ``'endian'``     The byte order (``'big'`` or ``'little'``)
+
+          ``'version'``    The Unified Model version to be used when
+                           decoding the header. Valid versions are,
+                           for example, ``4.2``, ``'6.6.3'`` and
+                           ``'8.2'``. The default version is
+                           ``4.5``. In general, a given version is
+                           ignored if it can be inferred from the
+                           header (which is usually the case for files
+                           created by the UM at versions 5.3 and
+                           later). The exception to this is when the
+                           given version has a third element (such as
+                           the 3 in 6.6.3), in which case any version
+                           in the header is ignored.
+          ===============  ===========================================
+
+        If format is specified as PP then the word size and byte order
+        default to ``4`` and ``'big'`` repsectively.
+
+            *Example:*
+              To specify that the input files are 32-bit, big-endian
+              PP files: ``um={'fmt': 'PP'}``
+
+            *Example:*
+              To specify that the input files are 32-bit,
+              little-endian PP files from version 5.1 of the Unified
+              Model: ``um={'fmt': 'PP', 'endian': 'little', 'version':
+              5.1}``
+
+        .. versionadded:: 1.5
+
 :Returns:
     
     out: `cf.FieldList` or `cf.Field`
@@ -248,6 +284,8 @@ Office (UK) fields files format files may be read.
 #    if 'all' in promote:
 #        promote = set(('field', 'coordinate', 'measure'))
         
+    if umversion is not None:
+        raise ValueError("The umversion parameter has been deprecated. Use the um parameter instead")    
 
     # Count the number of fields (in all files) and the number of
     # files
@@ -446,12 +484,20 @@ Read the contents of a single file into a field list.
     word_size = None
     endian    = None
     umversion = 405
+
     if um:
         ftype = 'UM' 
         fmt       = um.get('fmt')
         word_size = um.get('word_size')
         endian    = um.get('endian')
         umversion = um.get('version')
+        if fmt == 'PP':
+            # For PP format, there is a default word size and
+            # endian-ness
+            if word_size is None:
+                word_size = 4
+            if endian is None:
+                endian = 'big'
         if umversion is not None:
             umversion = float(str(umversion).replace('.', '0', 1))
     else:
